@@ -42,7 +42,7 @@ def test_model():
 
 
 def test_model_from_bleak():
-    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {}, -127)
+    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {})
     switchbot_adv = generate_advertisement_data(
         local_name="wohand", service_uuids=["cba20d00-224d-11e6-9fb8-0002a5d5c51b"]
     )
@@ -58,7 +58,7 @@ def test_model_from_bleak():
 
 
 def test_model_from_scanner():
-    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {}, -127)
+    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {})
     switchbot_adv = generate_advertisement_data(
         local_name="wohand", service_uuids=["cba20d00-224d-11e6-9fb8-0002a5d5c51b"]
     )
@@ -89,11 +89,12 @@ def test_model_from_scanner():
         "source": "local",
         "time": now,
         "tx_power": -127,
+        "raw": None,
     }
 
 
 def test_construct_service_info_bleak():
-    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {}, -127)
+    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {})
     switchbot_adv = generate_advertisement_data(
         local_name="wohand", service_uuids=["cba20d00-224d-11e6-9fb8-0002a5d5c51b"]
     )
@@ -135,12 +136,13 @@ def test_construct_service_info_bleak():
         "source": "local",
         "time": now,
         "tx_power": None,
+        "raw": None,
     }
 
 
 def test_from_device_and_advertisement_data():
     """Test creating a BluetoothServiceInfoBleak from a BLEDevice and AdvertisementData."""
-    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {}, -127)
+    switchbot_device = BLEDevice("44:44:33:11:23:45", "wohand", {})
     switchbot_adv = generate_advertisement_data(
         local_name="wohand", service_uuids=["cba20d00-224d-11e6-9fb8-0002a5d5c51b"]
     )
@@ -169,6 +171,7 @@ def test_from_device_and_advertisement_data():
         "source": "local",
         "time": now_monotonic,
         "tx_power": -127,
+        "raw": None,
     }
 
 
@@ -187,7 +190,7 @@ def test_pyobjc_compat():
     assert address == "44:44:33:11:23:45"
     assert rssi == -127
 
-    switchbot_device = BLEDevice(address, name, {}, rssi)
+    switchbot_device = BLEDevice(address, name, {})
     switchbot_adv = generate_advertisement_data(
         local_name=name, service_uuids=["cba20d00-224d-11e6-9fb8-0002a5d5c51b"]
     )
@@ -229,4 +232,5 @@ def test_pyobjc_compat():
         "source": "local",
         "time": now,
         "tx_power": None,
+        "raw": None,
     }
